import 'package:dio/dio.dart';
import 'package:flutter/widgets.dart';
import 'package:progamification/src/constants/service_urls.dart';
import 'package:progamification/src/utilities/http_client.dart';
import 'package:shared_preferences/shared_preferences.dart';

class LeaderBoardService with WidgetsBindingObserver {
  late SharedPreferences _prefs;

  LeaderBoardService() {
    _initPrefs();
    WidgetsBinding.instance.addObserver(this);
  }

  void _initPrefs() async {
    _prefs = await SharedPreferences.getInstance();
    // load any necessary data from prefs
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    if (state == AppLifecycleState.paused) {
      // save any necessary data to prefs when app is paused
      _prefs.setString('myData', 'myValue');
    }
  }

  Future<dynamic> getLeaderBoard(String userId, String applicationId) async {
    var httpClient = getHttpClient();
    Map<String, dynamic> bodyMap = {'userId': userId, 'appId': applicationId};

    Response response = await httpClient.post(
      ServiceUrls.getUserLeaderBoard,
      data: bodyMap,
      options: Options(
        headers: bodyMap,
      ),
    );

    return response.data;
  }

  Future<dynamic> getUserRewards(String userId, String applicationId) async {
    var httpClient = getHttpClient();
    Map<String, dynamic> bodyMap = {'userId': userId, 'appId': applicationId};
    Response response = await httpClient.post(
      ServiceUrls.getUserRewards,
      data: bodyMap,
      options: Options(
        headers: bodyMap,
      ),
    );
    if (response.statusCode! >= 400 && response.statusCode! <= 500) {
      throw Exception('Request failed with status: ${response.statusCode}.');
    }
    return response.data;
  }
}
